StringStoryConfig class
DTO class for string_story.yaml part
Constructors
- StringStoryConfig({required int versionCode, required String inputDirectory, required String outputDirectory, required String hashDirectory, String? translationProvider, String? translationModel, required String envFile})
- StringStoryConfig.fromYaml(Map? yaml)
-
factory
Properties
- envFile → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashDirectory → String
-
final
- inputDirectory → String
-
final
- outputDirectory → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- translationModel → String?
-
final
- translationProvider → String?
-
final
- versionCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited